@@ -1,14 +1,14 @@
 //! # Tinify Crate
 //!
 //! `tinify-rs` is a Rust client for the Tinify API.
-//! Used for TinyPNG and TinyJPG. Tinify compresses your images intelligently. 
-//! 
+//! Used for TinyPNG and TinyJPG. Tinify compresses your images intelligently.
+//!
 //! Read more at https://tinify.com
 // --snip--
 
-mod client;
-mod source;
-mod result;
-mod tmp_file;
 mod error;
+mod mock;
+mod client;
+mod result;
+mod source;
 pub mod tinify;
