@@ -18,7 +18,10 @@ impl<'a> Result<'a> {
     buffer: Option<&String>
   ) -> io::Result<()> {
     let url = buffer.as_deref().unwrap();
-    let img_bytes = blocking::get(url).unwrap().bytes().unwrap();
+    let img_bytes = blocking::get(url)
+      .unwrap()
+      .bytes()
+      .unwrap();
     fs::write(path, img_bytes)?;
     
     Ok(())
@@ -37,22 +40,17 @@ impl<'a> Result<'a> {
 #[cfg(test)]
 mod tests {
   use super::*;
-  use crate::create_file;
   use lazy_static::lazy_static;
   use std::sync::Mutex;
   use std::path::Path;
 
   lazy_static! {
-    static ref TMP_PATH: &'static str = "./tmp_test_image.png";
+    static ref TMP_PATH: &'static str = "./tmp_image.jpg";
     static ref TEST_BUFFER: Mutex<Vec<u8>> = Mutex::new(Vec::new());
   }
   
   #[test]
   fn test_to_buffer() {
-    let path = Path::new(*TMP_PATH);
-    if !path.exists() {
-      create_file!();
-    }
     let buffer = fs::read(Path::new(*TMP_PATH)).unwrap();
     for byte in buffer.iter() {
       TEST_BUFFER.lock().unwrap().push(*byte);
